@@ -17,7 +17,7 @@ from clu.legacy import LegacyActor
 from hal import __version__
 
 
-__all__ = ["HALActor"]
+__all__ = ["HALActor", "ActorHelpers"]
 
 
 T = TypeVar("T", bound="HALActor")
@@ -48,6 +48,7 @@ class ActorHelpers:
             APOGEEHelper,
             BOSSHelper,
             FFSHelper,
+            HALHelper,
             LampsHelper,
             Scripts,
             TCCHelper,
@@ -60,6 +61,14 @@ class ActorHelpers:
         self.lamps = LampsHelper(actor)
         self.tcc = TCCHelper(actor)
 
+        self.bypasses: set[str] = set(actor.config["bypasses"])
+        self._available_bypasses = ["all"]
+        self._available_bypasses += [
+            helper.name
+            for helper in HALHelper.__subclasses__()
+            if helper.name is not None
+        ]
+
         self.scripts = Scripts(actor, actor.config["scripts"])
 
         self.macros = {macro.name: macro for macro in all_macros}
